# _M.textadept.snapopen

Snapopen for the textadept module.

## Examples

    local snapopen = _M.textadept.snapopen.open

    -- Show all files in PATHS.
    snapopen()

    -- Show all files in the current file's directory.
    snapopen(buffer.filename:match('^(.+)[/\\]'), nil, true)

    -- Show all Lua files in PATHS.
    snapopen(nil, '!%.lua$')

    -- Ignore the project's 'images' folder and HTML pages.
    snapopen('/path/to/project', {
               folders = { 'images' },
               extensions = { 'html' }
             }, true)

- - -

## Fields

- - -

<a id="DEFAULT_DEPTH"></a>
### `DEFAULT_DEPTH` (number)

Maximum directory depth to search. The default value is `4`.

- - -

<a id="MAX"></a>
### `MAX` (number)

Maximum number of files to list. The default value is `1000`.

- - -


## Functions

- - -

<a id="open"></a>
### `open` (utf8\_paths, filter, exclude\_PATHS, exclude\_FILTER, depth)

Quickly open a file in set of directories.

Parameters:

* `utf8_paths`: A UTF-8 string directory path or table of UTF-8 directory
  paths to search.
* `filter`: A filter for files and folders to exclude. The filter may be
  a string or table. Each filter is a Lua pattern. Any files matching a
  filter are excluded. Prefix a pattern with `!` to exclude any files that
  do not match the filter. File extensions can be more efficiently excluded
  by adding the extension text to a table assigned to an `extensions` key in
  the filter table instead of using individual filters. Directories can be
  excluded by adding filters to a table assigned to a `folders` key in the
  filter table. All strings should be UTF-8 encoded.
* `exclude_PATHS`: Flag indicating whether or not to exclude `PATHS` in the
  search. The default value is `false`.
* `exclude_FILTER`: Flag indicating whether or not to exclude `FILTER` from
  `filter` in the search. If false, adds `FILTER` to the given `filter`.
  The default value is `false`.
* `depth`: Number of directories to recurse into for finding files.
  The default value is `DEFAULT_DEPTH`.

Usage:

* `_M.textadept.snapopen.open()`
* `_M.textadept.snapopen.open(buffer.filename:match('^.+/'), nil, true)`
* `_M.textadept.snapopen.open(nil, '!%.lua$')`
* `_M.textadept.snapopen.open(nil, { folders = { '%.hg' } })`

- - -


## Tables

- - -

<a id="FILTER"></a>
### `FILTER`

Default file and directory filters.

- - -

<a id="PATHS"></a>
### `PATHS`

Table of default UTF-8 paths to search.

- - -

